@@ -22,33 +22,33 @@ def process_extraction(url, html, image_urls = None):
     records = []
 
     
-    text = extract_text.get(url, html)
+    text = extract_text(url, html)
     records+=text
     
     soup = _get_soup(html)
 
 
-    links = extract_links.get(url, soup)
+    links = extract_links(url, soup)
     records+=links
 
 
-    images = extract_images.get(url, soup)
+    images = extract_images(url, soup)
     records += images
 
 
-    feeds = extract_feeds.get(url, soup)
+    feeds = extract_feeds(url, soup)
     records += feeds
 
-    schemas = extract_schemas.get(url, html)
+    schemas = extract_schemas(url, html)
     records += schemas
 
-    src = extract_src.get(url, soup)
+    src = extract_src(url, soup)
     records += src
 
-    texts = extract_text.get(url, html)
+    texts = extract_text(url, html)
     records += texts
 
-    titles = extract_title.get(url, soup)
+    titles = extract_title(url, soup)
     records += titles
 
 
